# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class TeamRemoveMemberRequest(BaseModel):
    """
    TeamRemoveMemberRequest
    """  # noqa: E501

    account_id: Optional[StrictStr] = Field(
        default=None,
        description="**account_id** or **email_address** is required. If both are provided, the account id prevails.  Account id to remove from your Team.",
    )
    email_address: Optional[StrictStr] = Field(
        default=None,
        description="**account_id** or **email_address** is required. If both are provided, the account id prevails.  Email address of the Account to remove from your Team.",
    )
    new_owner_email_address: Optional[StrictStr] = Field(
        default=None,
        description="The email address of an Account on this Team to receive all documents, templates, and API apps (if applicable) from the removed Account. If not provided, and on an Enterprise plan, this data will remain with the removed Account.  **NOTE:** Only available for Enterprise plans.",
    )
    new_team_id: Optional[StrictStr] = Field(
        default=None, description="Id of the new Team."
    )
    new_role: Optional[StrictStr] = Field(
        default=None,
        description="A new role member will take in a new Team.  **NOTE:** This parameter is used only if `new_team_id` is provided.",
    )
    __properties: ClassVar[List[str]] = [
        "account_id",
        "email_address",
        "new_owner_email_address",
        "new_team_id",
        "new_role",
    ]

    @field_validator("new_role")
    def new_role_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(["Member", "Developer", "Team Manager", "Admin"]):
            raise ValueError(
                "must be one of enum values ('Member', 'Developer', 'Team Manager', 'Admin')"
            )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TeamRemoveMemberRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TeamRemoveMemberRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "account_id": obj.get("account_id"),
                "email_address": obj.get("email_address"),
                "new_owner_email_address": obj.get("new_owner_email_address"),
                "new_team_id": obj.get("new_team_id"),
                "new_role": obj.get("new_role"),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "account_id": "(str,)",
            "email_address": "(str,)",
            "new_owner_email_address": "(str,)",
            "new_team_id": "(str,)",
            "new_role": "(str,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in []



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing_extensions import Annotated
from dropbox_sign.models.unclaimed_draft_create_embedded_request import (
    UnclaimedDraftCreateEmbeddedRequest,
)
from dropbox_sign.models.unclaimed_draft_create_embedded_with_template_request import (
    UnclaimedDraftCreateEmbeddedWithTemplateRequest,
)
from dropbox_sign.models.unclaimed_draft_create_request import (
    UnclaimedDraftCreateRequest,
)
from dropbox_sign.models.unclaimed_draft_create_response import (
    UnclaimedDraftCreateResponse,
)
from dropbox_sign.models.unclaimed_draft_edit_and_resend_request import (
    UnclaimedDraftEditAndResendRequest,
)

from dropbox_sign.api_client import ApiClient, RequestSerialized
from dropbox_sign.api_response import ApiResponse
from dropbox_sign.rest import RESTResponseType
import io


class UnclaimedDraftApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def unclaimed_draft_create(
        self,
        unclaimed_draft_create_request: UnclaimedDraftCreateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UnclaimedDraftCreateResponse:
        """Create Unclaimed Draft

        Creates a new Draft that can be claimed using the claim URL. The first authenticated user to access the URL will claim the Draft and will be shown either the \"Sign and send\" or the \"Request signature\" page with the Draft loaded. Subsequent access to the claim URL will result in a 404.

        :param unclaimed_draft_create_request: (required)
        :type unclaimed_draft_create_request: UnclaimedDraftCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_create_serialize(
            unclaimed_draft_create_request=unclaimed_draft_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def unclaimed_draft_create_with_http_info(
        self,
        unclaimed_draft_create_request: UnclaimedDraftCreateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UnclaimedDraftCreateResponse]:
        """Create Unclaimed Draft

        Creates a new Draft that can be claimed using the claim URL. The first authenticated user to access the URL will claim the Draft and will be shown either the \"Sign and send\" or the \"Request signature\" page with the Draft loaded. Subsequent access to the claim URL will result in a 404.

        :param unclaimed_draft_create_request: (required)
        :type unclaimed_draft_create_request: UnclaimedDraftCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_create_serialize(
            unclaimed_draft_create_request=unclaimed_draft_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def unclaimed_draft_create_without_preload_content(
        self,
        unclaimed_draft_create_request: UnclaimedDraftCreateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Unclaimed Draft

        Creates a new Draft that can be claimed using the claim URL. The first authenticated user to access the URL will claim the Draft and will be shown either the \"Sign and send\" or the \"Request signature\" page with the Draft loaded. Subsequent access to the claim URL will result in a 404.

        :param unclaimed_draft_create_request: (required)
        :type unclaimed_draft_create_request: UnclaimedDraftCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_create_serialize(
            unclaimed_draft_create_request=unclaimed_draft_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _unclaimed_draft_create_serialize(
        self,
        unclaimed_draft_create_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        has_files = False
        body_param = unclaimed_draft_create_request
        excluded_json_fields = set([])
        for param_name, param_type in body_param.openapi_types().items():
            param_value = getattr(body_param, param_name)
            if param_value is None:
                continue

            if "io.IOBase" in param_type:
                has_files = True
                _content_type = "multipart/form-data"
                excluded_json_fields.add(param_name)

                if isinstance(param_value, list):
                    for index, item in enumerate(param_value):
                        _files[f"{param_name}[{index}]"] = item
                else:
                    _files[param_name] = param_value

        if has_files is True:
            _form_params = body_param.to_json_form_params(excluded_json_fields)

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if unclaimed_draft_create_request is not None and has_files is False:
            _body_params = unclaimed_draft_create_request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json", "multipart/form-data"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["api_key", "oauth2"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/unclaimed_draft/create",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def unclaimed_draft_create_embedded(
        self,
        unclaimed_draft_create_embedded_request: UnclaimedDraftCreateEmbeddedRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UnclaimedDraftCreateResponse:
        """Create Embedded Unclaimed Draft

        Creates a new Draft that can be claimed and used in an embedded iFrame. The first authenticated user to access the URL will claim the Draft and will be shown the \"Request signature\" page with the Draft loaded. Subsequent access to the claim URL will result in a `404`. For this embedded endpoint the `requester_email_address` parameter is required.  **NOTE:** Embedded unclaimed drafts can only be accessed in embedded iFrames whereas normal drafts can be used and accessed on Dropbox Sign.

        :param unclaimed_draft_create_embedded_request: (required)
        :type unclaimed_draft_create_embedded_request: UnclaimedDraftCreateEmbeddedRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_create_embedded_serialize(
            unclaimed_draft_create_embedded_request=unclaimed_draft_create_embedded_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def unclaimed_draft_create_embedded_with_http_info(
        self,
        unclaimed_draft_create_embedded_request: UnclaimedDraftCreateEmbeddedRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UnclaimedDraftCreateResponse]:
        """Create Embedded Unclaimed Draft

        Creates a new Draft that can be claimed and used in an embedded iFrame. The first authenticated user to access the URL will claim the Draft and will be shown the \"Request signature\" page with the Draft loaded. Subsequent access to the claim URL will result in a `404`. For this embedded endpoint the `requester_email_address` parameter is required.  **NOTE:** Embedded unclaimed drafts can only be accessed in embedded iFrames whereas normal drafts can be used and accessed on Dropbox Sign.

        :param unclaimed_draft_create_embedded_request: (required)
        :type unclaimed_draft_create_embedded_request: UnclaimedDraftCreateEmbeddedRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_create_embedded_serialize(
            unclaimed_draft_create_embedded_request=unclaimed_draft_create_embedded_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def unclaimed_draft_create_embedded_without_preload_content(
        self,
        unclaimed_draft_create_embedded_request: UnclaimedDraftCreateEmbeddedRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Embedded Unclaimed Draft

        Creates a new Draft that can be claimed and used in an embedded iFrame. The first authenticated user to access the URL will claim the Draft and will be shown the \"Request signature\" page with the Draft loaded. Subsequent access to the claim URL will result in a `404`. For this embedded endpoint the `requester_email_address` parameter is required.  **NOTE:** Embedded unclaimed drafts can only be accessed in embedded iFrames whereas normal drafts can be used and accessed on Dropbox Sign.

        :param unclaimed_draft_create_embedded_request: (required)
        :type unclaimed_draft_create_embedded_request: UnclaimedDraftCreateEmbeddedRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_create_embedded_serialize(
            unclaimed_draft_create_embedded_request=unclaimed_draft_create_embedded_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _unclaimed_draft_create_embedded_serialize(
        self,
        unclaimed_draft_create_embedded_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        has_files = False
        body_param = unclaimed_draft_create_embedded_request
        excluded_json_fields = set([])
        for param_name, param_type in body_param.openapi_types().items():
            param_value = getattr(body_param, param_name)
            if param_value is None:
                continue

            if "io.IOBase" in param_type:
                has_files = True
                _content_type = "multipart/form-data"
                excluded_json_fields.add(param_name)

                if isinstance(param_value, list):
                    for index, item in enumerate(param_value):
                        _files[f"{param_name}[{index}]"] = item
                else:
                    _files[param_name] = param_value

        if has_files is True:
            _form_params = body_param.to_json_form_params(excluded_json_fields)

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if unclaimed_draft_create_embedded_request is not None and has_files is False:
            _body_params = unclaimed_draft_create_embedded_request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json", "multipart/form-data"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["api_key", "oauth2"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/unclaimed_draft/create_embedded",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def unclaimed_draft_create_embedded_with_template(
        self,
        unclaimed_draft_create_embedded_with_template_request: UnclaimedDraftCreateEmbeddedWithTemplateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UnclaimedDraftCreateResponse:
        """Create Embedded Unclaimed Draft with Template

        Creates a new Draft with a previously saved template(s) that can be claimed and used in an embedded iFrame. The first authenticated user to access the URL will claim the Draft and will be shown the \"Request signature\" page with the Draft loaded. Subsequent access to the claim URL will result in a `404`. For this embedded endpoint the `requester_email_address` parameter is required.  **NOTE:** Embedded unclaimed drafts can only be accessed in embedded iFrames whereas normal drafts can be used and accessed on Dropbox Sign.

        :param unclaimed_draft_create_embedded_with_template_request: (required)
        :type unclaimed_draft_create_embedded_with_template_request: UnclaimedDraftCreateEmbeddedWithTemplateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_create_embedded_with_template_serialize(
            unclaimed_draft_create_embedded_with_template_request=unclaimed_draft_create_embedded_with_template_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def unclaimed_draft_create_embedded_with_template_with_http_info(
        self,
        unclaimed_draft_create_embedded_with_template_request: UnclaimedDraftCreateEmbeddedWithTemplateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UnclaimedDraftCreateResponse]:
        """Create Embedded Unclaimed Draft with Template

        Creates a new Draft with a previously saved template(s) that can be claimed and used in an embedded iFrame. The first authenticated user to access the URL will claim the Draft and will be shown the \"Request signature\" page with the Draft loaded. Subsequent access to the claim URL will result in a `404`. For this embedded endpoint the `requester_email_address` parameter is required.  **NOTE:** Embedded unclaimed drafts can only be accessed in embedded iFrames whereas normal drafts can be used and accessed on Dropbox Sign.

        :param unclaimed_draft_create_embedded_with_template_request: (required)
        :type unclaimed_draft_create_embedded_with_template_request: UnclaimedDraftCreateEmbeddedWithTemplateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_create_embedded_with_template_serialize(
            unclaimed_draft_create_embedded_with_template_request=unclaimed_draft_create_embedded_with_template_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def unclaimed_draft_create_embedded_with_template_without_preload_content(
        self,
        unclaimed_draft_create_embedded_with_template_request: UnclaimedDraftCreateEmbeddedWithTemplateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Embedded Unclaimed Draft with Template

        Creates a new Draft with a previously saved template(s) that can be claimed and used in an embedded iFrame. The first authenticated user to access the URL will claim the Draft and will be shown the \"Request signature\" page with the Draft loaded. Subsequent access to the claim URL will result in a `404`. For this embedded endpoint the `requester_email_address` parameter is required.  **NOTE:** Embedded unclaimed drafts can only be accessed in embedded iFrames whereas normal drafts can be used and accessed on Dropbox Sign.

        :param unclaimed_draft_create_embedded_with_template_request: (required)
        :type unclaimed_draft_create_embedded_with_template_request: UnclaimedDraftCreateEmbeddedWithTemplateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_create_embedded_with_template_serialize(
            unclaimed_draft_create_embedded_with_template_request=unclaimed_draft_create_embedded_with_template_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _unclaimed_draft_create_embedded_with_template_serialize(
        self,
        unclaimed_draft_create_embedded_with_template_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        has_files = False
        body_param = unclaimed_draft_create_embedded_with_template_request
        excluded_json_fields = set([])
        for param_name, param_type in body_param.openapi_types().items():
            param_value = getattr(body_param, param_name)
            if param_value is None:
                continue

            if "io.IOBase" in param_type:
                has_files = True
                _content_type = "multipart/form-data"
                excluded_json_fields.add(param_name)

                if isinstance(param_value, list):
                    for index, item in enumerate(param_value):
                        _files[f"{param_name}[{index}]"] = item
                else:
                    _files[param_name] = param_value

        if has_files is True:
            _form_params = body_param.to_json_form_params(excluded_json_fields)

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if (
            unclaimed_draft_create_embedded_with_template_request is not None
            and has_files is False
        ):
            _body_params = unclaimed_draft_create_embedded_with_template_request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json", "multipart/form-data"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["api_key", "oauth2"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/unclaimed_draft/create_embedded_with_template",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def unclaimed_draft_edit_and_resend(
        self,
        signature_request_id: Annotated[
            StrictStr,
            Field(description="The ID of the signature request to edit and resend."),
        ],
        unclaimed_draft_edit_and_resend_request: UnclaimedDraftEditAndResendRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UnclaimedDraftCreateResponse:
        """Edit and Resend Unclaimed Draft

        Creates a new signature request from an embedded request that can be edited prior to being sent to the recipients. Parameter `test_mode` can be edited prior to request. Signers can be edited in embedded editor. Requester's email address will remain unchanged if `requester_email_address` parameter is not set.  **NOTE:** Embedded unclaimed drafts can only be accessed in embedded iFrames whereas normal drafts can be used and accessed on Dropbox Sign.

        :param signature_request_id: The ID of the signature request to edit and resend. (required)
        :type signature_request_id: str
        :param unclaimed_draft_edit_and_resend_request: (required)
        :type unclaimed_draft_edit_and_resend_request: UnclaimedDraftEditAndResendRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_edit_and_resend_serialize(
            signature_request_id=signature_request_id,
            unclaimed_draft_edit_and_resend_request=unclaimed_draft_edit_and_resend_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def unclaimed_draft_edit_and_resend_with_http_info(
        self,
        signature_request_id: Annotated[
            StrictStr,
            Field(description="The ID of the signature request to edit and resend."),
        ],
        unclaimed_draft_edit_and_resend_request: UnclaimedDraftEditAndResendRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UnclaimedDraftCreateResponse]:
        """Edit and Resend Unclaimed Draft

        Creates a new signature request from an embedded request that can be edited prior to being sent to the recipients. Parameter `test_mode` can be edited prior to request. Signers can be edited in embedded editor. Requester's email address will remain unchanged if `requester_email_address` parameter is not set.  **NOTE:** Embedded unclaimed drafts can only be accessed in embedded iFrames whereas normal drafts can be used and accessed on Dropbox Sign.

        :param signature_request_id: The ID of the signature request to edit and resend. (required)
        :type signature_request_id: str
        :param unclaimed_draft_edit_and_resend_request: (required)
        :type unclaimed_draft_edit_and_resend_request: UnclaimedDraftEditAndResendRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_edit_and_resend_serialize(
            signature_request_id=signature_request_id,
            unclaimed_draft_edit_and_resend_request=unclaimed_draft_edit_and_resend_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def unclaimed_draft_edit_and_resend_without_preload_content(
        self,
        signature_request_id: Annotated[
            StrictStr,
            Field(description="The ID of the signature request to edit and resend."),
        ],
        unclaimed_draft_edit_and_resend_request: UnclaimedDraftEditAndResendRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Edit and Resend Unclaimed Draft

        Creates a new signature request from an embedded request that can be edited prior to being sent to the recipients. Parameter `test_mode` can be edited prior to request. Signers can be edited in embedded editor. Requester's email address will remain unchanged if `requester_email_address` parameter is not set.  **NOTE:** Embedded unclaimed drafts can only be accessed in embedded iFrames whereas normal drafts can be used and accessed on Dropbox Sign.

        :param signature_request_id: The ID of the signature request to edit and resend. (required)
        :type signature_request_id: str
        :param unclaimed_draft_edit_and_resend_request: (required)
        :type unclaimed_draft_edit_and_resend_request: UnclaimedDraftEditAndResendRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unclaimed_draft_edit_and_resend_serialize(
            signature_request_id=signature_request_id,
            unclaimed_draft_edit_and_resend_request=unclaimed_draft_edit_and_resend_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "UnclaimedDraftCreateResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _unclaimed_draft_edit_and_resend_serialize(
        self,
        signature_request_id,
        unclaimed_draft_edit_and_resend_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        has_files = False
        body_param = unclaimed_draft_edit_and_resend_request
        excluded_json_fields = set([])
        for param_name, param_type in body_param.openapi_types().items():
            param_value = getattr(body_param, param_name)
            if param_value is None:
                continue

            if "io.IOBase" in param_type:
                has_files = True
                _content_type = "multipart/form-data"
                excluded_json_fields.add(param_name)

                if isinstance(param_value, list):
                    for index, item in enumerate(param_value):
                        _files[f"{param_name}[{index}]"] = item
                else:
                    _files[param_name] = param_value

        if has_files is True:
            _form_params = body_param.to_json_form_params(excluded_json_fields)

        # process the path parameters
        if signature_request_id is not None:
            _path_params["signature_request_id"] = signature_request_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if unclaimed_draft_edit_and_resend_request is not None and has_files is False:
            _body_params = unclaimed_draft_edit_and_resend_request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["api_key", "oauth2"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/unclaimed_draft/edit_and_resend/{signature_request_id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from dropbox_sign.models.signature_request_response_attachment import (
    SignatureRequestResponseAttachment,
)
from dropbox_sign.models.template_response_account import TemplateResponseAccount
from dropbox_sign.models.template_response_cc_role import TemplateResponseCCRole
from dropbox_sign.models.template_response_document import TemplateResponseDocument
from dropbox_sign.models.template_response_document_custom_field_base import (
    TemplateResponseDocumentCustomFieldBase,
)
from dropbox_sign.models.template_response_document_form_field_base import (
    TemplateResponseDocumentFormFieldBase,
)
from dropbox_sign.models.template_response_signer_role import TemplateResponseSignerRole
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class TemplateResponse(BaseModel):
    """
    Contains information about the templates you and your team have created.
    """  # noqa: E501

    template_id: Optional[StrictStr] = Field(
        default=None, description="The id of the Template."
    )
    title: Optional[StrictStr] = Field(
        default=None,
        description="The title of the Template. This will also be the default subject of the message sent to signers when using this Template to send a SignatureRequest. This can be overridden when sending the SignatureRequest.",
    )
    message: Optional[StrictStr] = Field(
        default=None,
        description="The default message that will be sent to signers when using this Template to send a SignatureRequest. This can be overridden when sending the SignatureRequest.",
    )
    updated_at: Optional[StrictInt] = Field(
        default=None, description="Time the template was last updated."
    )
    is_embedded: Optional[StrictBool] = Field(
        default=None,
        description="`true` if this template was created using an embedded flow, `false` if it was created on our website. Will be `null` when you are not the creator of the Template.",
    )
    is_creator: Optional[StrictBool] = Field(
        default=None,
        description="`true` if you are the owner of this template, `false` if it's been shared with you by a team member.",
    )
    can_edit: Optional[StrictBool] = Field(
        default=None,
        description="Indicates whether edit rights have been granted to you by the owner (always `true` if that's you).",
    )
    is_locked: Optional[StrictBool] = Field(
        default=None,
        description="Indicates whether the template is locked. If `true`, then the template was created outside your quota and can only be used in `test_mode`. If `false`, then the template is within your quota and can be used to create signature requests.",
    )
    metadata: Optional[Dict[str, Any]] = Field(
        default=None, description="The metadata attached to the template."
    )
    signer_roles: Optional[List[TemplateResponseSignerRole]] = Field(
        default=None,
        description="An array of the designated signer roles that must be specified when sending a SignatureRequest using this Template.",
    )
    cc_roles: Optional[List[TemplateResponseCCRole]] = Field(
        default=None,
        description="An array of the designated CC roles that must be specified when sending a SignatureRequest using this Template.",
    )
    documents: Optional[List[TemplateResponseDocument]] = Field(
        default=None,
        description="An array describing each document associated with this Template. Includes form field data for each document.",
    )
    custom_fields: Optional[List[TemplateResponseDocumentCustomFieldBase]] = Field(
        default=None,
        description="Deprecated. Use `custom_fields` inside the [documents](https://developers.hellosign.com/api/reference/operation/templateGet/#!c=200&path=template/documents&t=response) array instead.",
    )
    named_form_fields: Optional[List[TemplateResponseDocumentFormFieldBase]] = Field(
        default=None,
        description="Deprecated. Use `form_fields` inside the [documents](https://developers.hellosign.com/api/reference/operation/templateGet/#!c=200&path=template/documents&t=response) array instead.",
    )
    accounts: Optional[List[TemplateResponseAccount]] = Field(
        default=None, description="An array of the Accounts that can use this Template."
    )
    attachments: Optional[List[SignatureRequestResponseAttachment]] = Field(
        default=None, description="Signer attachments."
    )
    __properties: ClassVar[List[str]] = [
        "template_id",
        "title",
        "message",
        "updated_at",
        "is_embedded",
        "is_creator",
        "can_edit",
        "is_locked",
        "metadata",
        "signer_roles",
        "cc_roles",
        "documents",
        "custom_fields",
        "named_form_fields",
        "accounts",
        "attachments",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TemplateResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in signer_roles (list)
        _items = []
        if self.signer_roles:
            for _item_signer_roles in self.signer_roles:
                if _item_signer_roles:
                    _items.append(_item_signer_roles.to_dict())
            _dict["signer_roles"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in cc_roles (list)
        _items = []
        if self.cc_roles:
            for _item_cc_roles in self.cc_roles:
                if _item_cc_roles:
                    _items.append(_item_cc_roles.to_dict())
            _dict["cc_roles"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in documents (list)
        _items = []
        if self.documents:
            for _item_documents in self.documents:
                if _item_documents:
                    _items.append(_item_documents.to_dict())
            _dict["documents"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in custom_fields (list)
        _items = []
        if self.custom_fields:
            for _item_custom_fields in self.custom_fields:
                if _item_custom_fields:
                    _items.append(_item_custom_fields.to_dict())
            _dict["custom_fields"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in named_form_fields (list)
        _items = []
        if self.named_form_fields:
            for _item_named_form_fields in self.named_form_fields:
                if _item_named_form_fields:
                    _items.append(_item_named_form_fields.to_dict())
            _dict["named_form_fields"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in accounts (list)
        _items = []
        if self.accounts:
            for _item_accounts in self.accounts:
                if _item_accounts:
                    _items.append(_item_accounts.to_dict())
            _dict["accounts"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict["attachments"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TemplateResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "template_id": obj.get("template_id"),
                "title": obj.get("title"),
                "message": obj.get("message"),
                "updated_at": obj.get("updated_at"),
                "is_embedded": obj.get("is_embedded"),
                "is_creator": obj.get("is_creator"),
                "can_edit": obj.get("can_edit"),
                "is_locked": obj.get("is_locked"),
                "metadata": obj.get("metadata"),
                "signer_roles": (
                    [
                        TemplateResponseSignerRole.from_dict(_item)
                        for _item in obj["signer_roles"]
                    ]
                    if obj.get("signer_roles") is not None
                    else None
                ),
                "cc_roles": (
                    [
                        TemplateResponseCCRole.from_dict(_item)
                        for _item in obj["cc_roles"]
                    ]
                    if obj.get("cc_roles") is not None
                    else None
                ),
                "documents": (
                    [
                        TemplateResponseDocument.from_dict(_item)
                        for _item in obj["documents"]
                    ]
                    if obj.get("documents") is not None
                    else None
                ),
                "custom_fields": (
                    [
                        TemplateResponseDocumentCustomFieldBase.from_dict(_item)
                        for _item in obj["custom_fields"]
                    ]
                    if obj.get("custom_fields") is not None
                    else None
                ),
                "named_form_fields": (
                    [
                        TemplateResponseDocumentFormFieldBase.from_dict(_item)
                        for _item in obj["named_form_fields"]
                    ]
                    if obj.get("named_form_fields") is not None
                    else None
                ),
                "accounts": (
                    [
                        TemplateResponseAccount.from_dict(_item)
                        for _item in obj["accounts"]
                    ]
                    if obj.get("accounts") is not None
                    else None
                ),
                "attachments": (
                    [
                        SignatureRequestResponseAttachment.from_dict(_item)
                        for _item in obj["attachments"]
                    ]
                    if obj.get("attachments") is not None
                    else None
                ),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "template_id": "(str,)",
            "title": "(str,)",
            "message": "(str,)",
            "updated_at": "(int,)",
            "is_embedded": "(bool,)",
            "is_creator": "(bool,)",
            "can_edit": "(bool,)",
            "is_locked": "(bool,)",
            "metadata": "(object,)",
            "signer_roles": "(List[TemplateResponseSignerRole],)",
            "cc_roles": "(List[TemplateResponseCCRole],)",
            "documents": "(List[TemplateResponseDocument],)",
            "custom_fields": "(List[TemplateResponseDocumentCustomFieldBase],)",
            "named_form_fields": "(List[TemplateResponseDocumentFormFieldBase],)",
            "accounts": "(List[TemplateResponseAccount],)",
            "attachments": "(List[SignatureRequestResponseAttachment],)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "signer_roles",
            "cc_roles",
            "documents",
            "custom_fields",
            "named_form_fields",
            "accounts",
            "attachments",
        ]



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class BulkSendJobResponse(BaseModel):
    """
    Contains information about the BulkSendJob such as when it was created and how many signature requests are queued.
    """  # noqa: E501

    bulk_send_job_id: Optional[StrictStr] = Field(
        default=None, description="The id of the BulkSendJob."
    )
    total: Optional[StrictInt] = Field(
        default=None,
        description="The total amount of Signature Requests queued for sending.",
    )
    is_creator: Optional[StrictBool] = Field(
        default=None,
        description="True if you are the owner of this BulkSendJob, false if it's been shared with you by a team member.",
    )
    created_at: Optional[StrictInt] = Field(
        default=None, description="Time that the BulkSendJob was created."
    )
    __properties: ClassVar[List[str]] = [
        "bulk_send_job_id",
        "total",
        "is_creator",
        "created_at",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BulkSendJobResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BulkSendJobResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "bulk_send_job_id": obj.get("bulk_send_job_id"),
                "total": obj.get("total"),
                "is_creator": obj.get("is_creator"),
                "created_at": obj.get("created_at"),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "bulk_send_job_id": "(str,)",
            "total": "(int,)",
            "is_creator": "(bool,)",
            "created_at": "(int,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in []



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from dropbox_sign.models.signature_request_response_data_base import (
    SignatureRequestResponseDataBase,
)
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class SignatureRequestResponseDataValueCheckbox(SignatureRequestResponseDataBase):
    """
    SignatureRequestResponseDataValueCheckbox
    """  # noqa: E501

    type: Optional[StrictStr] = Field(
        default="checkbox", description="A yes/no checkbox"
    )
    value: Optional[StrictBool] = Field(
        default=None, description="The value of the form field."
    )
    __properties: ClassVar[List[str]] = [
        "api_id",
        "signature_id",
        "name",
        "required",
        "type",
        "value",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SignatureRequestResponseDataValueCheckbox from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SignatureRequestResponseDataValueCheckbox from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "api_id": obj.get("api_id"),
                "signature_id": obj.get("signature_id"),
                "name": obj.get("name"),
                "required": obj.get("required"),
                "type": obj.get("type") if obj.get("type") is not None else "checkbox",
                "value": obj.get("value"),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "type": "(str,)",
            "value": "(bool,)",
            "api_id": "(str,)",
            "signature_id": "(str,)",
            "name": "(str,)",
            "required": "(bool,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in []



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from dropbox_sign.models.event_callback_request_event_metadata import (
    EventCallbackRequestEventMetadata,
)
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class EventCallbackRequestEvent(BaseModel):
    """
    Basic information about the event that occurred.
    """  # noqa: E501

    event_time: StrictStr = Field(
        description="Time the event was created (using Unix time)."
    )
    event_type: StrictStr = Field(
        description="Type of callback event that was triggered."
    )
    event_hash: StrictStr = Field(
        description="Generated hash used to verify source of event data."
    )
    event_metadata: Optional[EventCallbackRequestEventMetadata] = None
    __properties: ClassVar[List[str]] = [
        "event_time",
        "event_type",
        "event_hash",
        "event_metadata",
    ]

    @field_validator("event_type")
    def event_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(
            [
                "account_confirmed",
                "unknown_error",
                "file_error",
                "sign_url_invalid",
                "signature_request_viewed",
                "signature_request_signed",
                "signature_request_sent",
                "signature_request_all_signed",
                "signature_request_email_bounce",
                "signature_request_remind",
                "signature_request_incomplete_qes",
                "signature_request_destroyed",
                "signature_request_canceled",
                "signature_request_downloadable",
                "signature_request_declined",
                "signature_request_reassigned",
                "signature_request_invalid",
                "signature_request_prepared",
                "signature_request_expired",
                "template_created",
                "template_error",
                "callback_test",
                "signature_request_signer_removed",
            ]
        ):
            raise ValueError(
                "must be one of enum values ('account_confirmed', 'unknown_error', 'file_error', 'sign_url_invalid', 'signature_request_viewed', 'signature_request_signed', 'signature_request_sent', 'signature_request_all_signed', 'signature_request_email_bounce', 'signature_request_remind', 'signature_request_incomplete_qes', 'signature_request_destroyed', 'signature_request_canceled', 'signature_request_downloadable', 'signature_request_declined', 'signature_request_reassigned', 'signature_request_invalid', 'signature_request_prepared', 'signature_request_expired', 'template_created', 'template_error', 'callback_test', 'signature_request_signer_removed')"
            )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EventCallbackRequestEvent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of event_metadata
        if self.event_metadata:
            _dict["event_metadata"] = self.event_metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EventCallbackRequestEvent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "event_time": obj.get("event_time"),
                "event_type": obj.get("event_type"),
                "event_hash": obj.get("event_hash"),
                "event_metadata": (
                    EventCallbackRequestEventMetadata.from_dict(obj["event_metadata"])
                    if obj.get("event_metadata") is not None
                    else None
                ),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "event_time": "(str,)",
            "event_type": "(str,)",
            "event_hash": "(str,)",
            "event_metadata": "(EventCallbackRequestEventMetadata,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in []



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from dropbox_sign.models.sub_editor_options import SubEditorOptions
from dropbox_sign.models.sub_merge_field import SubMergeField
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class EmbeddedEditUrlRequest(BaseModel):
    """
    EmbeddedEditUrlRequest
    """  # noqa: E501

    allow_edit_ccs: Optional[StrictBool] = Field(
        default=False,
        description="This allows the requester to enable/disable to add or change CC roles when editing the template.",
    )
    cc_roles: Optional[List[StrictStr]] = Field(
        default=None,
        description="The CC roles that must be assigned when using the template to send a signature request. To remove all CC roles, pass in a single role with no name. For use in a POST request.",
    )
    editor_options: Optional[SubEditorOptions] = None
    force_signer_roles: Optional[StrictBool] = Field(
        default=False,
        description="Provide users the ability to review/edit the template signer roles.",
    )
    force_subject_message: Optional[StrictBool] = Field(
        default=False,
        description="Provide users the ability to review/edit the template subject and message.",
    )
    merge_fields: Optional[List[SubMergeField]] = Field(
        default=None,
        description="Add additional merge fields to the template, which can be used used to pre-fill data by passing values into signature requests made with that template.  Remove all merge fields on the template by passing an empty array `[]`.",
    )
    preview_only: Optional[StrictBool] = Field(
        default=False,
        description="This allows the requester to enable the preview experience (i.e. does not allow the requester's end user to add any additional fields via the editor).  **NOTE:** This parameter overwrites `show_preview=true` (if set).",
    )
    show_preview: Optional[StrictBool] = Field(
        default=False,
        description="This allows the requester to enable the editor/preview experience.",
    )
    show_progress_stepper: Optional[StrictBool] = Field(
        default=True,
        description="When only one step remains in the signature request process and this parameter is set to `false` then the progress stepper will be hidden.",
    )
    test_mode: Optional[StrictBool] = Field(
        default=False,
        description="Whether this is a test, locked templates will only be available for editing if this is set to `true`. Defaults to `false`.",
    )
    __properties: ClassVar[List[str]] = [
        "allow_edit_ccs",
        "cc_roles",
        "editor_options",
        "force_signer_roles",
        "force_subject_message",
        "merge_fields",
        "preview_only",
        "show_preview",
        "show_progress_stepper",
        "test_mode",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EmbeddedEditUrlRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of editor_options
        if self.editor_options:
            _dict["editor_options"] = self.editor_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in merge_fields (list)
        _items = []
        if self.merge_fields:
            for _item_merge_fields in self.merge_fields:
                if _item_merge_fields:
                    _items.append(_item_merge_fields.to_dict())
            _dict["merge_fields"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EmbeddedEditUrlRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "allow_edit_ccs": (
                    obj.get("allow_edit_ccs")
                    if obj.get("allow_edit_ccs") is not None
                    else False
                ),
                "cc_roles": obj.get("cc_roles"),
                "editor_options": (
                    SubEditorOptions.from_dict(obj["editor_options"])
                    if obj.get("editor_options") is not None
                    else None
                ),
                "force_signer_roles": (
                    obj.get("force_signer_roles")
                    if obj.get("force_signer_roles") is not None
                    else False
                ),
                "force_subject_message": (
                    obj.get("force_subject_message")
                    if obj.get("force_subject_message") is not None
                    else False
                ),
                "merge_fields": (
                    [SubMergeField.from_dict(_item) for _item in obj["merge_fields"]]
                    if obj.get("merge_fields") is not None
                    else None
                ),
                "preview_only": (
                    obj.get("preview_only")
                    if obj.get("preview_only") is not None
                    else False
                ),
                "show_preview": (
                    obj.get("show_preview")
                    if obj.get("show_preview") is not None
                    else False
                ),
                "show_progress_stepper": (
                    obj.get("show_progress_stepper")
                    if obj.get("show_progress_stepper") is not None
                    else True
                ),
                "test_mode": (
                    obj.get("test_mode") if obj.get("test_mode") is not None else False
                ),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "allow_edit_ccs": "(bool,)",
            "cc_roles": "(List[str],)",
            "editor_options": "(SubEditorOptions,)",
            "force_signer_roles": "(bool,)",
            "force_subject_message": "(bool,)",
            "merge_fields": "(List[SubMergeField],)",
            "preview_only": "(bool,)",
            "show_preview": "(bool,)",
            "show_progress_stepper": "(bool,)",
            "test_mode": "(bool,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "cc_roles",
            "merge_fields",
        ]



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SubFormFieldsPerDocumentFontEnum(str, Enum):
    """
    SubFormFieldsPerDocumentFontEnum
    """

    """
    allowed enum values
    """
    HELVETICA = "helvetica"
    ARIAL = "arial"
    COURIER = "courier"
    CALIBRI = "calibri"
    CAMBRIA = "cambria"
    GEORGIA = "georgia"
    TIMES = "times"
    TREBUCHET = "trebuchet"
    VERDANA = "verdana"
    ROBOTO = "roboto"
    ROBOTOMONO = "robotoMono"
    NOTOSANS = "notoSans"
    NOTOSERIF = "notoSerif"
    NOTO_CJK_MINUS_JP_MINUS_REGULAR = "notoCJK-JP-Regular"
    NOTO_HEBREW_MINUS_REGULAR = "notoHebrew-Regular"
    NOTOSANTHAIMERGED = "notoSanThaiMerged"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SubFormFieldsPerDocumentFontEnum from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing_extensions import Annotated
from dropbox_sign.models.embedded_edit_url_request import EmbeddedEditUrlRequest
from dropbox_sign.models.embedded_edit_url_response import EmbeddedEditUrlResponse
from dropbox_sign.models.embedded_sign_url_response import EmbeddedSignUrlResponse

from dropbox_sign.api_client import ApiClient, RequestSerialized
from dropbox_sign.api_response import ApiResponse
from dropbox_sign.rest import RESTResponseType
import io


class EmbeddedApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def embedded_edit_url(
        self,
        template_id: Annotated[
            StrictStr, Field(description="The id of the template to edit.")
        ],
        embedded_edit_url_request: EmbeddedEditUrlRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> EmbeddedEditUrlResponse:
        """Get Embedded Template Edit URL

        Retrieves an embedded object containing a template url that can be opened in an iFrame. Note that only templates created via the embedded template process are available to be edited with this endpoint.

        :param template_id: The id of the template to edit. (required)
        :type template_id: str
        :param embedded_edit_url_request: (required)
        :type embedded_edit_url_request: EmbeddedEditUrlRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._embedded_edit_url_serialize(
            template_id=template_id,
            embedded_edit_url_request=embedded_edit_url_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "EmbeddedEditUrlResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def embedded_edit_url_with_http_info(
        self,
        template_id: Annotated[
            StrictStr, Field(description="The id of the template to edit.")
        ],
        embedded_edit_url_request: EmbeddedEditUrlRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[EmbeddedEditUrlResponse]:
        """Get Embedded Template Edit URL

        Retrieves an embedded object containing a template url that can be opened in an iFrame. Note that only templates created via the embedded template process are available to be edited with this endpoint.

        :param template_id: The id of the template to edit. (required)
        :type template_id: str
        :param embedded_edit_url_request: (required)
        :type embedded_edit_url_request: EmbeddedEditUrlRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._embedded_edit_url_serialize(
            template_id=template_id,
            embedded_edit_url_request=embedded_edit_url_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "EmbeddedEditUrlResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def embedded_edit_url_without_preload_content(
        self,
        template_id: Annotated[
            StrictStr, Field(description="The id of the template to edit.")
        ],
        embedded_edit_url_request: EmbeddedEditUrlRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Embedded Template Edit URL

        Retrieves an embedded object containing a template url that can be opened in an iFrame. Note that only templates created via the embedded template process are available to be edited with this endpoint.

        :param template_id: The id of the template to edit. (required)
        :type template_id: str
        :param embedded_edit_url_request: (required)
        :type embedded_edit_url_request: EmbeddedEditUrlRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._embedded_edit_url_serialize(
            template_id=template_id,
            embedded_edit_url_request=embedded_edit_url_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "EmbeddedEditUrlResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _embedded_edit_url_serialize(
        self,
        template_id,
        embedded_edit_url_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        has_files = False
        body_param = embedded_edit_url_request
        excluded_json_fields = set([])
        for param_name, param_type in body_param.openapi_types().items():
            param_value = getattr(body_param, param_name)
            if param_value is None:
                continue

            if "io.IOBase" in param_type:
                has_files = True
                _content_type = "multipart/form-data"
                excluded_json_fields.add(param_name)

                if isinstance(param_value, list):
                    for index, item in enumerate(param_value):
                        _files[f"{param_name}[{index}]"] = item
                else:
                    _files[param_name] = param_value

        if has_files is True:
            _form_params = body_param.to_json_form_params(excluded_json_fields)

        # process the path parameters
        if template_id is not None:
            _path_params["template_id"] = template_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if embedded_edit_url_request is not None and has_files is False:
            _body_params = embedded_edit_url_request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["api_key", "oauth2"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/embedded/edit_url/{template_id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def embedded_sign_url(
        self,
        signature_id: Annotated[
            StrictStr,
            Field(description="The id of the signature to get a signature url for."),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> EmbeddedSignUrlResponse:
        """Get Embedded Sign URL

        Retrieves an embedded object containing a signature url that can be opened in an iFrame. Note that templates created via the embedded template process will only be accessible through the API.

        :param signature_id: The id of the signature to get a signature url for. (required)
        :type signature_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._embedded_sign_url_serialize(
            signature_id=signature_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "EmbeddedSignUrlResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def embedded_sign_url_with_http_info(
        self,
        signature_id: Annotated[
            StrictStr,
            Field(description="The id of the signature to get a signature url for."),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[EmbeddedSignUrlResponse]:
        """Get Embedded Sign URL

        Retrieves an embedded object containing a signature url that can be opened in an iFrame. Note that templates created via the embedded template process will only be accessible through the API.

        :param signature_id: The id of the signature to get a signature url for. (required)
        :type signature_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._embedded_sign_url_serialize(
            signature_id=signature_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "EmbeddedSignUrlResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def embedded_sign_url_without_preload_content(
        self,
        signature_id: Annotated[
            StrictStr,
            Field(description="The id of the signature to get a signature url for."),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Embedded Sign URL

        Retrieves an embedded object containing a signature url that can be opened in an iFrame. Note that templates created via the embedded template process will only be accessible through the API.

        :param signature_id: The id of the signature to get a signature url for. (required)
        :type signature_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._embedded_sign_url_serialize(
            signature_id=signature_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "EmbeddedSignUrlResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _embedded_sign_url_serialize(
        self,
        signature_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if signature_id is not None:
            _path_params["signature_id"] = signature_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["api_key", "oauth2"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/embedded/sign_url/{signature_id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from dropbox_sign.models.template_response_document_custom_field_base import (
    TemplateResponseDocumentCustomFieldBase,
)
from dropbox_sign.models.template_response_document_field_group import (
    TemplateResponseDocumentFieldGroup,
)
from dropbox_sign.models.template_response_document_form_field_base import (
    TemplateResponseDocumentFormFieldBase,
)
from dropbox_sign.models.template_response_document_static_field_base import (
    TemplateResponseDocumentStaticFieldBase,
)
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class TemplateResponseDocument(BaseModel):
    """
    TemplateResponseDocument
    """  # noqa: E501

    name: Optional[StrictStr] = Field(
        default=None, description="Name of the associated file."
    )
    index: Optional[StrictInt] = Field(
        default=None,
        description="Document ordering, the lowest index is displayed first and the highest last (0-based indexing).",
    )
    field_groups: Optional[List[TemplateResponseDocumentFieldGroup]] = Field(
        default=None, description="An array of Form Field Group objects."
    )
    form_fields: Optional[List[TemplateResponseDocumentFormFieldBase]] = Field(
        default=None,
        description="An array of Form Field objects containing the name and type of each named field.",
    )
    custom_fields: Optional[List[TemplateResponseDocumentCustomFieldBase]] = Field(
        default=None,
        description="An array of Form Field objects containing the name and type of each named field.",
    )
    static_fields: Optional[List[TemplateResponseDocumentStaticFieldBase]] = Field(
        default=None,
        description="An array describing static overlay fields. **NOTE:** Only available for certain subscriptions.",
    )
    __properties: ClassVar[List[str]] = [
        "name",
        "index",
        "field_groups",
        "form_fields",
        "custom_fields",
        "static_fields",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TemplateResponseDocument from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in field_groups (list)
        _items = []
        if self.field_groups:
            for _item_field_groups in self.field_groups:
                if _item_field_groups:
                    _items.append(_item_field_groups.to_dict())
            _dict["field_groups"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in form_fields (list)
        _items = []
        if self.form_fields:
            for _item_form_fields in self.form_fields:
                if _item_form_fields:
                    _items.append(_item_form_fields.to_dict())
            _dict["form_fields"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in custom_fields (list)
        _items = []
        if self.custom_fields:
            for _item_custom_fields in self.custom_fields:
                if _item_custom_fields:
                    _items.append(_item_custom_fields.to_dict())
            _dict["custom_fields"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in static_fields (list)
        _items = []
        if self.static_fields:
            for _item_static_fields in self.static_fields:
                if _item_static_fields:
                    _items.append(_item_static_fields.to_dict())
            _dict["static_fields"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TemplateResponseDocument from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "name": obj.get("name"),
                "index": obj.get("index"),
                "field_groups": (
                    [
                        TemplateResponseDocumentFieldGroup.from_dict(_item)
                        for _item in obj["field_groups"]
                    ]
                    if obj.get("field_groups") is not None
                    else None
                ),
                "form_fields": (
                    [
                        TemplateResponseDocumentFormFieldBase.from_dict(_item)
                        for _item in obj["form_fields"]
                    ]
                    if obj.get("form_fields") is not None
                    else None
                ),
                "custom_fields": (
                    [
                        TemplateResponseDocumentCustomFieldBase.from_dict(_item)
                        for _item in obj["custom_fields"]
                    ]
                    if obj.get("custom_fields") is not None
                    else None
                ),
                "static_fields": (
                    [
                        TemplateResponseDocumentStaticFieldBase.from_dict(_item)
                        for _item in obj["static_fields"]
                    ]
                    if obj.get("static_fields") is not None
                    else None
                ),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "name": "(str,)",
            "index": "(int,)",
            "field_groups": "(List[TemplateResponseDocumentFieldGroup],)",
            "form_fields": "(List[TemplateResponseDocumentFormFieldBase],)",
            "custom_fields": "(List[TemplateResponseDocumentCustomFieldBase],)",
            "static_fields": "(List[TemplateResponseDocumentStaticFieldBase],)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "field_groups",
            "form_fields",
            "custom_fields",
            "static_fields",
        ]



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class SubFormFieldRuleTrigger(BaseModel):
    """
    SubFormFieldRuleTrigger
    """  # noqa: E501

    id: StrictStr = Field(
        description="Must reference the `api_id` of an existing field defined within `form_fields_per_document`. Trigger and action fields and groups must belong to the same signer."
    )
    operator: StrictStr = Field(
        description="Different field types allow different `operator` values: - Field type of **text**:   - **is**: exact match   - **not**: not exact match   - **match**: regular expression, without /. Example:     - OK `[a-zA-Z0-9]`     - Not OK `/[a-zA-Z0-9]/` - Field type of **dropdown**:   - **is**: exact match, single value   - **not**: not exact match, single value   - **any**: exact match, array of values.   - **none**: not exact match, array of values. - Field type of **checkbox**:   - **is**: exact match, single value   - **not**: not exact match, single value - Field type of **radio**:   - **is**: exact match, single value   - **not**: not exact match, single value"
    )
    value: Optional[StrictStr] = Field(
        default=None,
        description="**value** or **values** is required, but not both.  The value to match against **operator**.  - When **operator** is one of the following, **value** must be `String`:   - `is`   - `not`   - `match`  Otherwise, - **checkbox**: When **type** of trigger is **checkbox**, **value** must be `0` or `1` - **radio**: When **type** of trigger is **radio**, **value** must be `1`",
    )
    values: Optional[List[StrictStr]] = Field(
        default=None,
        description="**values** or **value** is required, but not both.  The values to match against **operator** when it is one of the following:  - `any` - `none`",
    )
    __properties: ClassVar[List[str]] = ["id", "operator", "value", "values"]

    @field_validator("operator")
    def operator_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(["any", "is", "match", "none", "not"]):
            raise ValueError(
                "must be one of enum values ('any', 'is', 'match', 'none', 'not')"
            )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SubFormFieldRuleTrigger from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SubFormFieldRuleTrigger from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "operator": obj.get("operator"),
                "value": obj.get("value"),
                "values": obj.get("values"),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "id": "(str,)",
            "operator": "(str,)",
            "value": "(str,)",
            "values": "(List[str],)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "values",
        ]



# coding: utf-8

# flake8: noqa
"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from dropbox_sign.models.account_create_request import AccountCreateRequest
from dropbox_sign.models.account_create_response import AccountCreateResponse
from dropbox_sign.models.account_get_response import AccountGetResponse
from dropbox_sign.models.account_response import AccountResponse
from dropbox_sign.models.account_response_quotas import AccountResponseQuotas
from dropbox_sign.models.account_response_usage import AccountResponseUsage
from dropbox_sign.models.account_update_request import AccountUpdateRequest
from dropbox_sign.models.account_verify_request import AccountVerifyRequest
from dropbox_sign.models.account_verify_response import AccountVerifyResponse
from dropbox_sign.models.account_verify_response_account import (
    AccountVerifyResponseAccount,
)
from dropbox_sign.models.api_app_create_request import ApiAppCreateRequest
from dropbox_sign.models.api_app_get_response import ApiAppGetResponse
from dropbox_sign.models.api_app_list_response import ApiAppListResponse
from dropbox_sign.models.api_app_response import ApiAppResponse
from dropbox_sign.models.api_app_response_o_auth import ApiAppResponseOAuth
from dropbox_sign.models.api_app_response_options import ApiAppResponseOptions
from dropbox_sign.models.api_app_response_owner_account import (
    ApiAppResponseOwnerAccount,
)
from dropbox_sign.models.api_app_response_white_labeling_options import (
    ApiAppResponseWhiteLabelingOptions,
)
from dropbox_sign.models.api_app_update_request import ApiAppUpdateRequest
from dropbox_sign.models.bulk_send_job_get_response import BulkSendJobGetResponse
from dropbox_sign.models.bulk_send_job_get_response_signature_requests import (
    BulkSendJobGetResponseSignatureRequests,
)
from dropbox_sign.models.bulk_send_job_list_response import BulkSendJobListResponse
from dropbox_sign.models.bulk_send_job_response import BulkSendJobResponse
from dropbox_sign.models.bulk_send_job_send_response import BulkSendJobSendResponse
from dropbox_sign.models.embedded_edit_url_request import EmbeddedEditUrlRequest
from dropbox_sign.models.embedded_edit_url_response import EmbeddedEditUrlResponse
from dropbox_sign.models.embedded_edit_url_response_embedded import (
    EmbeddedEditUrlResponseEmbedded,
)
from dropbox_sign.models.embedded_sign_url_response import EmbeddedSignUrlResponse
from dropbox_sign.models.embedded_sign_url_response_embedded import (
    EmbeddedSignUrlResponseEmbedded,
)
from dropbox_sign.models.error_response import ErrorResponse
from dropbox_sign.models.error_response_error import ErrorResponseError
from dropbox_sign.models.event_callback_request import EventCallbackRequest
from dropbox_sign.models.event_callback_request_event import EventCallbackRequestEvent
from dropbox_sign.models.event_callback_request_event_metadata import (
    EventCallbackRequestEventMetadata,
)
from dropbox_sign.models.fax_get_response import FaxGetResponse
from dropbox_sign.models.fax_line_add_user_request import FaxLineAddUserRequest
from dropbox_sign.models.fax_line_area_code_get_country_enum import (
    FaxLineAreaCodeGetCountryEnum,
)
from dropbox_sign.models.fax_line_area_code_get_province_enum import (
    FaxLineAreaCodeGetProvinceEnum,
)
from dropbox_sign.models.fax_line_area_code_get_response import (
    FaxLineAreaCodeGetResponse,
)
from dropbox_sign.models.fax_line_area_code_get_state_enum import (
    FaxLineAreaCodeGetStateEnum,
)
from dropbox_sign.models.fax_line_create_request import FaxLineCreateRequest
from dropbox_sign.models.fax_line_delete_request import FaxLineDeleteRequest
from dropbox_sign.models.fax_line_list_response import FaxLineListResponse
from dropbox_sign.models.fax_line_remove_user_request import FaxLineRemoveUserRequest
from dropbox_sign.models.fax_line_response import FaxLineResponse
from dropbox_sign.models.fax_line_response_fax_line import FaxLineResponseFaxLine
from dropbox_sign.models.fax_list_response import FaxListResponse
from dropbox_sign.models.fax_response import FaxResponse
from dropbox_sign.models.fax_response_transmission import FaxResponseTransmission
from dropbox_sign.models.fax_send_request import FaxSendRequest
from dropbox_sign.models.file_response import FileResponse
from dropbox_sign.models.file_response_data_uri import FileResponseDataUri
from dropbox_sign.models.list_info_response import ListInfoResponse
from dropbox_sign.models.o_auth_token_generate_request import OAuthTokenGenerateRequest
from dropbox_sign.models.o_auth_token_refresh_request import OAuthTokenRefreshRequest
from dropbox_sign.models.o_auth_token_response import OAuthTokenResponse
from dropbox_sign.models.report_create_request import ReportCreateRequest
from dropbox_sign.models.report_create_response import ReportCreateResponse
from dropbox_sign.models.report_response import ReportResponse
from dropbox_sign.models.signature_request_bulk_create_embedded_with_template_request import (
    SignatureRequestBulkCreateEmbeddedWithTemplateRequest,
)
from dropbox_sign.models.signature_request_bulk_send_with_template_request import (
    SignatureRequestBulkSendWithTemplateRequest,
)
from dropbox_sign.models.signature_request_create_embedded_request import (
    SignatureRequestCreateEmbeddedRequest,
)
from dropbox_sign.models.signature_request_create_embedded_with_template_request import (
    SignatureRequestCreateEmbeddedWithTemplateRequest,
)
from dropbox_sign.models.signature_request_get_response import (
    SignatureRequestGetResponse,
)
from dropbox_sign.models.signature_request_list_response import (
    SignatureRequestListResponse,
)
from dropbox_sign.models.signature_request_remind_request import (
    SignatureRequestRemindRequest,
)
from dropbox_sign.models.signature_request_response import SignatureRequestResponse
from dropbox_sign.models.signature_request_response_attachment import (
    SignatureRequestResponseAttachment,
)
from dropbox_sign.models.signature_request_response_custom_field_base import (
    SignatureRequestResponseCustomFieldBase,
)
from dropbox_sign.models.signature_request_response_custom_field_checkbox import (
    SignatureRequestResponseCustomFieldCheckbox,
)
from dropbox_sign.models.signature_request_response_custom_field_text import (
    SignatureRequestResponseCustomFieldText,
)
from dropbox_sign.models.signature_request_response_custom_field_type_enum import (
    SignatureRequestResponseCustomFieldTypeEnum,
)
from dropbox_sign.models.signature_request_response_data_base import (
    SignatureRequestResponseDataBase,
)
from dropbox_sign.models.signature_request_response_data_type_enum import (
    SignatureRequestResponseDataTypeEnum,
)
from dropbox_sign.models.signature_request_response_data_value_checkbox import (
    SignatureRequestResponseDataValueCheckbox,
)
from dropbox_sign.models.signature_request_response_data_value_checkbox_merge import (
    SignatureRequestResponseDataValueCheckboxMerge,
)
from dropbox_sign.models.signature_request_response_data_value_date_signed import (
    SignatureRequestResponseDataValueDateSigned,
)
from dropbox_sign.models.signature_request_response_data_value_dropdown import (
    SignatureRequestResponseDataValueDropdown,
)
from dropbox_sign.models.signature_request_response_data_value_initials import (
    SignatureRequestResponseDataValueInitials,
)
from dropbox_sign.models.signature_request_response_data_value_radio import (
    SignatureRequestResponseDataValueRadio,
)
from dropbox_sign.models.signature_request_response_data_value_signature import (
    SignatureRequestResponseDataValueSignature,
)
from dropbox_sign.models.signature_request_response_data_value_text import (
    SignatureRequestResponseDataValueText,
)
from dropbox_sign.models.signature_request_response_data_value_text_merge import (
    SignatureRequestResponseDataValueTextMerge,
)
from dropbox_sign.models.signature_request_response_signatures import (
    SignatureRequestResponseSignatures,
)
from dropbox_sign.models.signature_request_send_request import (
    SignatureRequestSendRequest,
)
from dropbox_sign.models.signature_request_send_with_template_request import (
    SignatureRequestSendWithTemplateRequest,
)
from dropbox_sign.models.signature_request_update_request import (
    SignatureRequestUpdateRequest,
)
from dropbox_sign.models.sub_attachment import SubAttachment
from dropbox_sign.models.sub_bulk_signer_list import SubBulkSignerList
from dropbox_sign.models.sub_bulk_signer_list_custom_field import (
    SubBulkSignerListCustomField,
)
from dropbox_sign.models.sub_cc import SubCC
from dropbox_sign.models.sub_custom_field import SubCustomField
from dropbox_sign.models.sub_editor_options import SubEditorOptions
from dropbox_sign.models.sub_field_options import SubFieldOptions
from dropbox_sign.models.sub_form_field_group import SubFormFieldGroup
from dropbox_sign.models.sub_form_field_rule import SubFormFieldRule
from dropbox_sign.models.sub_form_field_rule_action import SubFormFieldRuleAction
from dropbox_sign.models.sub_form_field_rule_trigger import SubFormFieldRuleTrigger
from dropbox_sign.models.sub_form_fields_per_document_base import (
    SubFormFieldsPerDocumentBase,
)
from dropbox_sign.models.sub_form_fields_per_document_checkbox import (
    SubFormFieldsPerDocumentCheckbox,
)
from dropbox_sign.models.sub_form_fields_per_document_checkbox_merge import (
    SubFormFieldsPerDocumentCheckboxMerge,
)
from dropbox_sign.models.sub_form_fields_per_document_date_signed import (
    SubFormFieldsPerDocumentDateSigned,
)
from dropbox_sign.models.sub_form_fields_per_document_dropdown import (
    SubFormFieldsPerDocumentDropdown,
)
from dropbox_sign.models.sub_form_fields_per_document_font_enum import (
    SubFormFieldsPerDocumentFontEnum,
)
from dropbox_sign.models.sub_form_fields_per_document_hyperlink import (
    SubFormFieldsPerDocumentHyperlink,
)
from dropbox_sign.models.sub_form_fields_per_document_initials import (
    SubFormFieldsPerDocumentInitials,
)
from dropbox_sign.models.sub_form_fields_per_document_radio import (
    SubFormFieldsPerDocumentRadio,
)
from dropbox_sign.models.sub_form_fields_per_document_signature import (
    SubFormFieldsPerDocumentSignature,
)
from dropbox_sign.models.sub_form_fields_per_document_text import (
    SubFormFieldsPerDocumentText,
)
from dropbox_sign.models.sub_form_fields_per_document_text_merge import (
    SubFormFieldsPerDocumentTextMerge,
)
from dropbox_sign.models.sub_form_fields_per_document_type_enum import (
    SubFormFieldsPerDocumentTypeEnum,
)
from dropbox_sign.models.sub_merge_field import SubMergeField
from dropbox_sign.models.sub_o_auth import SubOAuth
from dropbox_sign.models.sub_options import SubOptions
from dropbox_sign.models.sub_signature_request_grouped_signers import (
    SubSignatureRequestGroupedSigners,
)
from dropbox_sign.models.sub_signature_request_signer import SubSignatureRequestSigner
from dropbox_sign.models.sub_signature_request_template_signer import (
    SubSignatureRequestTemplateSigner,
)
from dropbox_sign.models.sub_signing_options import SubSigningOptions
from dropbox_sign.models.sub_team_response import SubTeamResponse
from dropbox_sign.models.sub_template_role import SubTemplateRole
from dropbox_sign.models.sub_unclaimed_draft_signer import SubUnclaimedDraftSigner
from dropbox_sign.models.sub_unclaimed_draft_template_signer import (
    SubUnclaimedDraftTemplateSigner,
)
from dropbox_sign.models.sub_white_labeling_options import SubWhiteLabelingOptions
from dropbox_sign.models.team_add_member_request import TeamAddMemberRequest
from dropbox_sign.models.team_create_request import TeamCreateRequest
from dropbox_sign.models.team_get_info_response import TeamGetInfoResponse
from dropbox_sign.models.team_get_response import TeamGetResponse
from dropbox_sign.models.team_info_response import TeamInfoResponse
from dropbox_sign.models.team_invite_response import TeamInviteResponse
from dropbox_sign.models.team_invites_response import TeamInvitesResponse
from dropbox_sign.models.team_member_response import TeamMemberResponse
from dropbox_sign.models.team_members_response import TeamMembersResponse
from dropbox_sign.models.team_parent_response import TeamParentResponse
from dropbox_sign.models.team_remove_member_request import TeamRemoveMemberRequest
from dropbox_sign.models.team_response import TeamResponse
from dropbox_sign.models.team_sub_teams_response import TeamSubTeamsResponse
from dropbox_sign.models.team_update_request import TeamUpdateRequest
from dropbox_sign.models.template_add_user_request import TemplateAddUserRequest
from dropbox_sign.models.template_create_embedded_draft_request import (
    TemplateCreateEmbeddedDraftRequest,
)
from dropbox_sign.models.template_create_embedded_draft_response import (
    TemplateCreateEmbeddedDraftResponse,
)
from dropbox_sign.models.template_create_embedded_draft_response_template import (
    TemplateCreateEmbeddedDraftResponseTemplate,
)
from dropbox_sign.models.template_create_request import TemplateCreateRequest
from dropbox_sign.models.template_create_response import TemplateCreateResponse
from dropbox_sign.models.template_create_response_template import (
    TemplateCreateResponseTemplate,
)
from dropbox_sign.models.template_edit_response import TemplateEditResponse
from dropbox_sign.models.template_get_response import TemplateGetResponse
from dropbox_sign.models.template_list_response import TemplateListResponse
from dropbox_sign.models.template_remove_user_request import TemplateRemoveUserRequest
from dropbox_sign.models.template_response import TemplateResponse
from dropbox_sign.models.template_response_account import TemplateResponseAccount
from dropbox_sign.models.template_response_account_quota import (
    TemplateResponseAccountQuota,
)
from dropbox_sign.models.template_response_cc_role import TemplateResponseCCRole
from dropbox_sign.models.template_response_document import TemplateResponseDocument
from dropbox_sign.models.template_response_document_custom_field_base import (
    TemplateResponseDocumentCustomFieldBase,
)
from dropbox_sign.models.template_response_document_custom_field_checkbox import (
    TemplateResponseDocumentCustomFieldCheckbox,
)
from dropbox_sign.models.template_response_document_custom_field_text import (
    TemplateResponseDocumentCustomFieldText,
)
from dropbox_sign.models.template_response_document_field_group import (
    TemplateResponseDocumentFieldGroup,
)
from dropbox_sign.models.template_response_document_field_group_rule import (
    TemplateResponseDocumentFieldGroupRule,
)
from dropbox_sign.models.template_response_document_form_field_base import (
    TemplateResponseDocumentFormFieldBase,
)
from dropbox_sign.models.template_response_document_form_field_checkbox import (
    TemplateResponseDocumentFormFieldCheckbox,
)
from dropbox_sign.models.template_response_document_form_field_date_signed import (
    TemplateResponseDocumentFormFieldDateSigned,
)
from dropbox_sign.models.template_response_document_form_field_dropdown import (
    TemplateResponseDocumentFormFieldDropdown,
)
from dropbox_sign.models.template_response_document_form_field_hyperlink import (
    TemplateResponseDocumentFormFieldHyperlink,
)
from dropbox_sign.models.template_response_document_form_field_initials import (
    TemplateResponseDocumentFormFieldInitials,
)
from dropbox_sign.models.template_response_document_form_field_radio import (
    TemplateResponseDocumentFormFieldRadio,
)
from dropbox_sign.models.template_response_document_form_field_signature import (
    TemplateResponseDocumentFormFieldSignature,
)
from dropbox_sign.models.template_response_document_form_field_text import (
    TemplateResponseDocumentFormFieldText,
)
from dropbox_sign.models.template_response_document_static_field_base import (
    TemplateResponseDocumentStaticFieldBase,
)
from dropbox_sign.models.template_response_document_static_field_checkbox import (
    TemplateResponseDocumentStaticFieldCheckbox,
)
from dropbox_sign.models.template_response_document_static_field_date_signed import (
    TemplateResponseDocumentStaticFieldDateSigned,
)
from dropbox_sign.models.template_response_document_static_field_dropdown import (
    TemplateResponseDocumentStaticFieldDropdown,
)
from dropbox_sign.models.template_response_document_static_field_hyperlink import (
    TemplateResponseDocumentStaticFieldHyperlink,
)
from dropbox_sign.models.template_response_document_static_field_initials import (
    TemplateResponseDocumentStaticFieldInitials,
)
from dropbox_sign.models.template_response_document_static_field_radio import (
    TemplateResponseDocumentStaticFieldRadio,
)
from dropbox_sign.models.template_response_document_static_field_signature import (
    TemplateResponseDocumentStaticFieldSignature,
)
from dropbox_sign.models.template_response_document_static_field_text import (
    TemplateResponseDocumentStaticFieldText,
)
from dropbox_sign.models.template_response_field_avg_text_length import (
    TemplateResponseFieldAvgTextLength,
)
from dropbox_sign.models.template_response_signer_role import TemplateResponseSignerRole
from dropbox_sign.models.template_update_files_request import TemplateUpdateFilesRequest
from dropbox_sign.models.template_update_files_response import (
    TemplateUpdateFilesResponse,
)
from dropbox_sign.models.template_update_files_response_template import (
    TemplateUpdateFilesResponseTemplate,
)
from dropbox_sign.models.unclaimed_draft_create_embedded_request import (
    UnclaimedDraftCreateEmbeddedRequest,
)
from dropbox_sign.models.unclaimed_draft_create_embedded_with_template_request import (
    UnclaimedDraftCreateEmbeddedWithTemplateRequest,
)
from dropbox_sign.models.unclaimed_draft_create_request import (
    UnclaimedDraftCreateRequest,
)
from dropbox_sign.models.unclaimed_draft_create_response import (
    UnclaimedDraftCreateResponse,
)
from dropbox_sign.models.unclaimed_draft_edit_and_resend_request import (
    UnclaimedDraftEditAndResendRequest,
)
from dropbox_sign.models.unclaimed_draft_response import UnclaimedDraftResponse
from dropbox_sign.models.warning_response import WarningResponse
